jd8440Animations = {};
jd8440Animations.ptoAnimation = "ptoLeverEngage";
jd8440Animations.tiltSteeringAnimation = "ColumnAdjust";

function jd8440Animations.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Washable, specializations)
		and SpecializationUtil.hasSpecialization(Motorized, specializations)
		and SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations);
end;

function jd8440Animations.registerEventListeners(vehicleType)
	SpecializationUtil.registerEventListener(vehicleType, "onLoad", jd8440Animations);
	SpecializationUtil.registerEventListener(vehicleType, "onUpdate", jd8440Animations);
end;

function jd8440Animations:onLoad(savegame)
	self.hasPTOanimation = false;
	self.hasTiltSteeringAnimation = false;
	if hasXMLProperty(self.xmlFile, "vehicle.powerTakeOffs.indicatorLamp") then
		self.ptoLamp = I3DUtil.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.powerTakeOffs.indicatorLamp#node"), self.i3dMappings);
		setVisibility(self.ptoLamp, false);
	end;
	if self.ptoLamp == nil then
		print("error locating ptoLamp node");
	end;
	if hasXMLProperty(self.xmlFile, "vehicle.animations") then
		if self:getAnimationExists(jd8440Animations.ptoAnimation) then
			self.hasPTOanimation = true;
		end;
		if self:getAnimationExists(jd8440Animations.tiltSteeringAnimation) then
			self.hasTiltSteeringAnimation = true;
		end;
	end;
	if not self.hasPTOanimation then
		print("error locating ptoLeverAnimation");
	end;
	if not self.hasTiltSteeringAnimation then
		print("error locating SteeringTiltAnimation");
	end;
		--[[i = 0;
		local foundAnimations = 0;
		local numberOfAnimations = 2;
		while true do
			local animationName = getXMLString(self.xmlFile, string.format("vehicle.animations.animation(%d)#name)", i));
			if animationName == "nil" then break; end;
			if animationName == "ptoLeverEngage" then
				self.hasPTOanimation = true;
				foundAnimations = foundAnimations +1;
			elseif animationName == "ColumnAdjust" then
				self.hasTiltSteeringAnimation = true;
				foundAnimations = foundAnimations +1;
			end;
			if foundAnimations >= numberOfAnimations then break; end;
			i = i + 1;
		end;]]
end;

function jd8440Animations:updatePTOAnimation(self, dt)
	local spec = self.spec_animatedVehicle;
	if self:getIsMotorStarted() then
		local ptoIsOn = false;
		local attachedImplements;
		if self.getAttachedImplements ~= nil then
			attachedImplements = self:getAttachedImplements();
		end;
		if attachedImplements ~= nil then
			for _, implement in pairs(attachedImplements) do
				if implement.object ~= nil then
					if implement.object.getIsTurnedOn ~= nil and implement.object:getIsTurnedOn() then
						ptoIsOn = true;
						break;
					end;
				end;
			end;
		end;
		local animName = jd8440Animations.ptoAnimation;
		if not self:getIsAnimationPlaying(animName) then
			if ptoIsOn and self:getAnimationTime(animName) <= 0 then
				self:playAnimation(animName, 10);
				if not getVisibility(self.ptoLamp) then
					setVisibility(self.ptoLamp, true);
				end;
			elseif not ptoIsOn and self:getAnimationTime(animName) >= 1 then
				self:playAnimation(animName, -10);
				if getVisibility(self.ptoLamp) then
					setVisibility(self.ptoLamp, false);
				end;
			end;
		end;
	else
		local animName = jd8440Animations.ptoAnimation;
		if self:getAnimationTime(animName) >= 1 then
			self:playAnimation(animName, -10);
		end;
		if getVisibility(self.ptoLamp) then
			setVisibility(self.ptoLamp, false);
		end;
	end;
end;

function jd8440Animations:updateTiltSteeringAnimation(self, dt)
	local spec = self.spec_animatedVehicle;
	local animName = jd8440Animations.tiltSteeringAnimation;
	if self:getIsEntered() then
		if (not self:getIsAnimationPlaying(animName) and self:getAnimationTime(animName) <= 0) or (self:getIsAnimationPlaying(animName) and spec.animations[animName].currentSpeed < 0) then
			self:playAnimation(animName, 1.5);
		end;
	elseif not self:getIsAIActive() then
		if not self:getIsAnimationPlaying(animName) and self:getAnimationTime(animName) >= 1 or (self:getIsAnimationPlaying(animName) and spec.animations[animName].currentSpeed > 0) then
			self:playAnimation(animName, -0.5);
		end;
	end;
end;

function jd8440Animations:onUpdate(dt)
	if self.hasPTOanimation then
		jd8440Animations:updatePTOAnimation(self, dt);
	end;
	if self.hasTiltSteeringAnimation then
		jd8440Animations:updateTiltSteeringAnimation(self, dt);
	end;
end;
